==> hoteldruid-mod-de_2.3.0-1.zip: de/disponibilita.php <==
<?php

switch ($messaggio) {

case "Le date sono sbagliate":                  $messaggio = "Datum liegt in der Vergangenheit"; break;
case "persone":                                 $messaggio = "Personen"; break;
case "La settimana dal":                        $messaggio = "Der Woche von"; break;
case "Il giorno dal":                           $messaggio = "Die Nacht vom"; break;
case "al":                                      $messaggio = "bis"; break;
case "è piena":                                 $messaggio = "ist voll"; break;
case "è pieno":                                 $messaggio = "ist belegt"; break;
case "<b>C'è</b> ancora disponibilità nel periodo richiesto":        $messaggio = "Es ist noch etwas verf&uuml;gbar im gew&uuml;nschten Zeitraum"; break;
case "<b>Non c'è</b> più disponibilità nel periodo richiesto":        $messaggio = "Im angegebenen Zeitraum ist nichts mehr verf&uuml;gbar."; break;
case "Si potrebbe inserire la prenotazione dividendola in":        $messaggio = "Die Reservierung k&ouml;nnte eingetragen werden, wenn sie zerlegt wird in"; break;
case "parti":                                   $messaggio = "Teile"; break;
case "Periodo di":                              $messaggio = "Zeitraum:"; break;
case "dal":                                     $messaggio = "von"; break;
case "settimane":                               $messaggio = "Wochen"; break;
case "giorni":                                  $messaggio = "Tage"; break;
case "Tariffa":                                 $messaggio = "Preis"; break;
case "compresi":                                $messaggio = "inklusive"; break;
case "di costi aggiuntivi fissi":               $messaggio = "von fixen Aufschl&auml;ge"; break;
case "Ricontrolla":                             $messaggio = "Nochmal pr&uuml;fen"; break;
case "Torna al menù principale":                $messaggio = "Zum Hauptmen&uuml;"; break;
case "con la tariffa":                          $messaggio = "zum Preis"; break;
case "Inserisci la prenotazione":               $messaggio = "Reservierung eintragen"; break;
case "settimana":                               $messaggio = "Woche"; break;
case "giorno":                                  $messaggio = "Tag"; break;
case "TOTALE":                                  $messaggio = "GESAMT"; break;
case "Non c'è nussun periodo delle regole 1 in cui sia consentito inserire prenotazioni per l'utente":        $messaggio = "Es gibt keine Zeitr&auml;ume in der Zuweisungsregel 1 in der es m&ouml;glich ist Reservierungen einzugeben f&uuml;r den Kunden"; break;
case "costo aggiuntivo unico":                      $messaggio = "Einmaliger Zuschlag"; break;
case "costo aggiuntivo settimanale":                $messaggio = "w&ouml;chentlicher Zuschlag"; break;
case "costo aggiuntivo giornaliero":                $messaggio = "t&auml;glicher Zuschlag"; break;
case "nº di settimane da applicare":                $messaggio = "Anzahl der anzuwendenden Wochen"; break;
case "nº di giorni da applicare":                   $messaggio = "Zahl der anzuwendenden Tage"; break;
case "di costi aggiuntivi":                         $messaggio = "an Zuschl&auml;gen"; break;
case "Aggiungi":                                    $messaggio = "Hinzuf&uuml;gen"; break;
case "da moltiplicare per":                         $messaggio = "multiplizieren mit"; break;
case "Non si sono potuti applicare alla tariffa uno o più costi":       $messaggio = "Es war nicht m&ouml;glich, die Zuschl&auml;ge auf den Tarif anzuwenden"; break;
case "Scegliere le settimane in cui applicare il costo aggiuntivo":     $messaggio = "W&auml;hlen Sie die Wochen, auf die die Zuschl&auml;ge angewendet werden sollen."; break;
case "Continua":                                                        $messaggio = "Weiter"; break;
case "tariffa":                                                         $messaggio = "Tarif"; break;
case "Quadro indicativo disponibilità":                                 $messaggio = "Verf&uuml;gbarkeits&uuml;bersicht"; break;
case "potrebbe non essere preciso":                                     $messaggio = "m&ouml;glicherweise nicht genau"; break;
case "persona":                                                         $messaggio = "Person"; break;
case "Caparra":                                                         $messaggio = "Anzahlung"; break;
case "con i costi aggiuntivi selezionati":                              $messaggio = "mit ausgew&auml;hlten Extra-Kosten"; break;
case "per":                                                             $messaggio = "f&uuml;r"; break;
case ", ma si dovranno fare degli spostamenti nei periodi della <div style=\"display: inline; color: blue;\">regola di assegnazione 1</div>":	$messaggio = ", but some movements will have to be made in periods of <div style=\"display: inline; color: blue;\">assignment rule 1</div>"; break;
case "documento di tipo":  			$messaggio = "document type"; break;
case "visualizza":  				$messaggio = "view"; break;
case "Commissioni":  				$messaggio = "Commissions"; break;
case "Non c'è nessuna tariffa disponibile in questo periodo":	$messaggio = "There are no available rates in this period"; break;
case "Mostra le tariffe non disponibili":  	$messaggio = "Show not available rates"; break;
case "Scegliere le settimane in cui applicare il costo aggiuntivo":	$messaggio = "Choose the weeks to be applied for the extra cost"; break;
case "Scegliere i giorni in cui applicare il costo aggiuntivo":	$messaggio = "Choose the days to be applied for the extra cost"; break;
case "costo aggiuntivo":  			$messaggio = "extra cost"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>

==> hoteldruid-mod-de_3.0.8-1.zip: de/disponibilita.php <==
<?php

switch ($messaggio) {

case "Le date sono sbagliate":                  $messaggio = "Datum liegt in der Vergangenheit"; break;
case "persone":                                 $messaggio = "Personen"; break;
case "La settimana dal":                        $messaggio = "Der Woche von"; break;
case "Il giorno dal":                           $messaggio = "Die Nacht vom"; break;
case "al":                                      $messaggio = "bis"; break;
case "è piena":                                 $messaggio = "ist voll"; break;
case "è pieno":                                 $messaggio = "ist belegt"; break;
case "<b>C'è</b> ancora disponibilità nel periodo richiesto":        $messaggio = "Es ist noch etwas verf&uuml;gbar im gew&uuml;nschten Zeitraum"; break;
case "<b>Non c'è</b> più disponibilità nel periodo richiesto":        $messaggio = "Im angegebenen Zeitraum ist nichts mehr verf&uuml;gbar."; break;
case "Si potrebbe inserire la prenotazione dividendola in":        $messaggio = "Die Reservierung k&ouml;nnte eingetragen werden, wenn sie zerlegt wird in"; break;
case "parti":                                   $messaggio = "Teile"; break;
case "Periodo di":                              $messaggio = "Zeitraum:"; break;
case "dal":                                     $messaggio = "von"; break;
case "settimane":                               $messaggio = "Wochen"; break;
case "giorni":                                  $messaggio = "Tage"; break;
case "Tariffa":                                 $messaggio = "Preis"; break;
case "compresi":                                $messaggio = "inklusive"; break;
case "di costi aggiuntivi fissi":               $messaggio = "von fixen Aufschl&auml;ge"; break;
case "Ricontrolla":                             $messaggio = "Nochmal pr&uuml;fen"; break;
case "Torna al menù principale":                $messaggio = "Zum Hauptmen&uuml;"; break;
case "con la tariffa":                          $messaggio = "zum Preis"; break;
case "Inserisci la prenotazione":               $messaggio = "Reservierung eintragen"; break;
case "settimana":                               $messaggio = "Woche"; break;
case "giorno":                                  $messaggio = "Tag"; break;
case "TOTALE":                                  $messaggio = "GESAMT"; break;
case "Non c'è nussun periodo delle regole 1 in cui sia consentito inserire prenotazioni per l'utente":        $messaggio = "Es gibt keine Zeitr&auml;ume in der Zuweisungsregel 1 in der es m&ouml;glich ist Reservierungen einzugeben f&uuml;r den Kunden"; break;
case "costo aggiuntivo unico":                      $messaggio = "Einmaliger Zuschlag"; break;
case "costo aggiuntivo settimanale":                $messaggio = "w&ouml;chentlicher Zuschlag"; break;
case "costo aggiuntivo giornaliero":                $messaggio = "t&auml;glicher Zuschlag"; break;
case "nº di settimane da applicare":                $messaggio = "Anzahl der anzuwendenden Wochen"; break;
case "nº di giorni da applicare":                   $messaggio = "Zahl der anzuwendenden Tage"; break;
case "di costi aggiuntivi":                         $messaggio = "an Zuschl&auml;gen"; break;
case "Aggiungi":                                    $messaggio = "Hinzuf&uuml;gen"; break;
case "da moltiplicare per":                         $messaggio = "multiplizieren mit"; break;
case "Non si sono potuti applicare alla tariffa uno o più costi":       $messaggio = "Es war nicht m&ouml;glich, die Zuschl&auml;ge auf den Tarif anzuwenden"; break;
case "Scegliere le settimane in cui applicare il costo aggiuntivo":     $messaggio = "W&auml;hlen Sie die Wochen, auf die die Zuschl&auml;ge angewendet werden sollen."; break;
case "Continua":                                                        $messaggio = "Weiter"; break;
case "tariffa":                                                         $messaggio = "Tarif"; break;
case "Quadro indicativo disponibilità":                                 $messaggio = "Verf&uuml;gbarkeits&uuml;bersicht"; break;
case "potrebbe non essere preciso":                                     $messaggio = "m&ouml;glicherweise nicht genau"; break;
case "persona":                                                         $messaggio = "Person"; break;
case "Caparra":                                                         $messaggio = "Anzahlung"; break;
case "con i costi aggiuntivi selezionati":                              $messaggio = "mit ausgew&auml;hlten Extra-Kosten"; break;
case "per":                                                             $messaggio = "f&uuml;r"; break;
case "Disponibilità":  				$messaggio = "Availability"; break;
case ", ma si dovranno fare degli spostamenti nei periodi della <div style=\"display: inline; color: blue;\">regola di assegnazione 1</div>":	$messaggio = ", but some movements will have to be made in periods of <div style=\"display: inline; color: blue;\">assignment rule 1</div>"; break;
case "documento di tipo":  			$messaggio = "document type"; break;
case "visualizza":  				$messaggio = "view"; break;
case "Commissioni":  				$messaggio = "Commissions"; break;
case "Non c'è nessuna tariffa disponibile in questo periodo":	$messaggio = "There are no available rates in this period"; break;
case "Mostra le tariffe non disponibili":  	$messaggio = "Show not available rates"; break;
case "Scegliere le settimane in cui applicare il costo aggiuntivo":	$messaggio = "Choose the weeks to be applied for the extra cost"; break;
case "Scegliere i giorni in cui applicare il costo aggiuntivo":	$messaggio = "Choose the days to be applied for the extra cost"; break;
case "costo aggiuntivo":  			$messaggio = "extra cost"; break;
case "non disponibile":  			$messaggio = "not available"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>
